@@ -1,3 +1,4 @@
+from enum import Enum
 from urllib.parse import SplitResult
 
 import pytest
@@ -235,12 +236,6 @@ def test_compressed_ipv6():
     assert url.host == url.raw_host
 
 
-def test_ipv6_zone():
-    url = URL("http://[fe80::822a:a8ff:fe49:470c%тест%42]:123")
-    assert url.raw_host == "fe80::822a:a8ff:fe49:470c%тест%42"
-    assert url.host == url.raw_host
-
-
 def test_ipv4_zone():
     # I'm unsure if it is correct.
     url = URL("http://1.2.3.4%тест%42:123")
@@ -719,6 +714,18 @@ def test_div_path_starting_from_slash_is_forbidden():
         url / "/to/others"
 
 
+class StrEnum(str, Enum):
+    spam = "ham"
+
+    def __str__(self):
+        return self.value
+
+
+def test_div_path_srting_subclass():
+    url = URL("http://example.com/path/") / StrEnum.spam
+    assert str(url) == "http://example.com/path/ham"
+
+
 def test_div_bad_type():
     url = URL("http://example.com/path/")
     with pytest.raises(TypeError):
@@ -797,6 +804,21 @@ def test_div_with_dots():
             "http://example.com/path/to",
             id="cleanup-query-and-fragment",
         ),
+        pytest.param("", ("path/",), "http://example.com/path/", id="trailing-slash"),
+        pytest.param(
+            "", ("path/", "to/"), "http://example.com/path/to/", id="duplicate-slash"
+        ),
+        pytest.param("", (), "http://example.com", id="empty-segments"),
+        pytest.param(
+            "/", ("path/",), "http://example.com/path/", id="base-slash-trailing-slash"
+        ),
+        pytest.param(
+            "/",
+            ("path/", "to/"),
+            "http://example.com/path/to/",
+            id="base-slash-duplicate-slash",
+        ),
+        pytest.param("/", (), "http://example.com", id="base-slash-empty-segments"),
     ],
 )
 def test_joinpath(base, to_join, expected):
@@ -811,6 +833,9 @@ def test_joinpath(base, to_join, expected):
         pytest.param(URL("a"), ("b",), ("a", "b"), id="relative-path"),
         pytest.param(URL("a"), ("b", "", "c"), ("a", "b", "c"), id="empty-element"),
         pytest.param(URL("/a"), ("b"), ("/", "a", "b"), id="absolute-path"),
+        pytest.param(URL(), ("a/",), ("a", ""), id="trailing-slash"),
+        pytest.param(URL(), ("a/", "b/"), ("a", "b", ""), id="duplicate-slash"),
+        pytest.param(URL(), (), ("",), id="empty-segments"),
     ],
 )
 def test_joinpath_relative(url, to_join, expected):
@@ -1629,8 +1654,8 @@ def test_human_repr_delimiters():
     s = url.human_repr()
     assert URL(s) == url
     assert (
-        s == "http:// !\"%23$%25&'()*+,-.%2F%3A;<=>%3F%40[\\]^_`{|}~"
-        ": !\"%23$%25&'()*+,-.%2F%3A;<=>%3F%40[\\]^_`{|}~"
+        s == "http:// !\"%23$%25&'()*+,-.%2F%3A;<=>%3F%40%5B\\%5D^_`{|}~"
+        ": !\"%23$%25&'()*+,-.%2F%3A;<=>%3F%40%5B\\%5D^_`{|}~"
         "@хост.домен:8080"
         "/ !\"%23$%25&'()*+,-./:;<=>%3F@[\\]^_`{|}~"
         "? !\"%23$%25%26'()*%2B,-./:%3B<%3D>?@[\\]^_`{|}~"
