@@ -341,9 +341,9 @@ class URL:
         return self._val > other._val
 
     def __truediv__(self, name):
-        if not type(name) is str:
+        if not isinstance(name, str):
             return NotImplemented
-        return self._make_child((name,))
+        return self._make_child((str(name),))
 
     def __mod__(self, query):
         return self.update_query(query)
@@ -713,7 +713,8 @@ class URL:
 
     def _make_child(self, segments, encoded=False):
         """add segments to self._val.path, accounting for absolute vs relative paths"""
-        parsed = []
+        # keep the trailing slash if the last segment ends with /
+        parsed = [""] if segments and segments[-1][-1:] == "/" else []
         for seg in reversed(segments):
             if not seg:
                 continue
@@ -734,6 +735,10 @@ class URL:
             parsed = [*old_path.rstrip("/").split("/"), *parsed]
         if self.is_absolute():
             parsed = _normalize_path_segments(parsed)
+            if parsed and parsed[0] != "":
+                # inject a leading slash when adding a path to an absolute URL
+                # where there was none before
+                parsed = ["", *parsed]
         new_path = "/".join(parsed)
         return URL(
             self._val._replace(path=new_path, query="", fragment=""), encoded=True
@@ -1113,8 +1118,8 @@ class URL:
 
     def human_repr(self):
         """Return decoded human readable string for URL representation."""
-        user = _human_quote(self.user, "#/:?@")
-        password = _human_quote(self.password, "#/:?@")
+        user = _human_quote(self.user, "#/:?@[]")
+        password = _human_quote(self.password, "#/:?@[]")
         host = self.host
         if host:
             host = self._encode_host(self.host, human=True)
